@@ -7,7 +7,7 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(spawn receive msg snd quit wt snd_wt listener open_node);
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use Carp;
 use IO::Select;
@@ -379,6 +379,7 @@ sub ipc_loop(;$$) {
  				delete $r_bufs{$fh};
  				delete $w_bufs{$fh};
 				delete $fh2fh{$fh};
+				delete $snd{$fh};
 				delete $pack{$fh};
 				delete $unpack{$fh};
 				if (my $node_vpid = $node{$fh}) {
@@ -543,6 +544,8 @@ To detect spawn closing message SPAWN_CLOSED handler should be defined:
 Note, for your convenience "close" and "exit" messages are special.
 If a process is sent a "close" or "exit" message, then any messages from it are ignored, SPAWN_CLOSED and NODE_CLOSED too.
 
+To break receive use "quit" subroutine.
+
 =head2 Dataflow programming
 
 Sometimes you may need to get additional information from other processes and only then continue the message processing. For this you may send a message with information request and then wait information getting in a proper place by subprogram wt (abbreviated "wait"), without current message processing break.
